@@ -103,15 +103,14 @@ def encrypt(
     dry_run: bool,
     passphrase_cmd: Optional[str],
     dtr_id: Optional[int] = None,
-    offline: bool = False,
     verify_dtr: Optional[bool] = None,
     **kwargs,
 ):
     if verify_dtr is None:
-        verify_dtr = not offline and dtr_id is not None
-    if offline and verify_dtr:
+        verify_dtr = not config.offline and dtr_id is not None
+    if config.offline and verify_dtr:
         raise UserError(
-            "--verify_dtr is not possible when offline is enabled in the config"
+            "--verify_dtr is not possible when offline is enabled in the config."
         )
     if config.sign_encrypted_data and not dry_run:
         kwargs["passphrase"] = get_passphrase_from_cmd_or_prompt(
@@ -123,7 +122,6 @@ def encrypt(
         return workflows_encrypt(
             *args,
             dtr_id=dtr_id,
-            offline=offline,
             verify_dtr=verify_dtr,
             config=config,
             dry_run=dry_run,
@@ -231,18 +229,18 @@ class Cli(Subcommands):
         Subcommand(
             decorate(
                 encrypt,
-                partial(config=config, offline=config.offline),
+                partial(config=config),
                 lazy_partial(progress=CliProgress),
             ),
             overrides={
                 "files": dict(help="Input file(s) or directories."),
                 "sender": dict(
-                    help="fingerprint, key ID or email associated "
+                    help="Fingerprint, key ID or email associated "
                     "with GPG key of data sender.",
                     alias="-s",
                 ),
                 "recipient": dict(
-                    help="fingerprint, key ID or email associated with "
+                    help="Fingerprint, key ID or email associated with "
                     "GPG key of data recipient(s).",
                     alias="-r",
                 ),
@@ -258,7 +256,7 @@ class Cli(Subcommands):
                     help="Ignore errors about missing disk space", alias="-f"
                 ),
                 "output": dict(
-                    help="output path (file or directory) to the "
+                    help="Output path (file or directory) to the "
                     "encrypted package. If no path is specified, "
                     "the output package is saved in the current working "
                     "directory. If this argument is missing or path is a "
@@ -267,10 +265,10 @@ class Cli(Subcommands):
                     default=None,
                     alias="-o",
                 ),
-                "output_suffix": dict(help="output file name suffix (optional)"),
+                "output_suffix": dict(help="Output file name suffix (optional)"),
                 "dry_run": dry_run_override,
                 "compression_level": dict(
-                    help="compression level for inner tarball in the range "
+                    help="Compression level for inner tarball in the range "
                     "0 (no compression) to 9 (highest compression). "
                     "Higher compression levels require more computing "
                     "time."
@@ -285,7 +283,7 @@ class Cli(Subcommands):
                 lazy_partial(progress=CliProgress),
             ),
             overrides={
-                "files": dict(help="Input file(s) or directories"),
+                "files": dict(help="Path(s) to encrypted package(s)"),
                 "protocol": dict(
                     help="The protocol for the file transfer."
                     "Currently available: {}".format(", ".join(available_protocols)),
@@ -314,6 +312,7 @@ class Cli(Subcommands):
                 decrypt, partial(config=config), lazy_partial(progress=CliProgress)
             ),
             overrides={
+                "files": dict(help="Path(s) to encrypted package(s)"),
                 "output_dir": dict(
                     help="Output directory.", default=os.getcwd(), alias="-o"
                 ),
