@@ -11,7 +11,9 @@ class SubcommandBase:
     """Abstract definition for a single command.
     Accept by the Subcommands._add function"""
 
-    def __init__(self, name, action, arguments, help=None):  # pylint: disable=redefined-builtin
+    def __init__(
+        self, name, action, arguments, help=None
+    ):  # pylint: disable=redefined-builtin
         self.name = name
         self.help = help
         self.action = action
@@ -27,6 +29,7 @@ class Subcommands:
     Add subcommands by deriving from this class and specify
     commands in the static :subcommands: variable
     """
+
     description: Optional[str] = None
     required = True
     subcommands: Tuple[SubcommandBase, ...] = ()
@@ -35,12 +38,11 @@ class Subcommands:
     def __init__(self, *args, **kwargs):
         parser = argparse.ArgumentParser(
             description=self.description,
-            formatter_class=argparse.RawDescriptionHelpFormatter)
+            formatter_class=argparse.RawDescriptionHelpFormatter,
+        )
         if self.version is not None:
-            parser.add_argument('--version', action='version',
-                                version=self.version)
-        subparsers = parser.add_subparsers(
-            dest='action', help='Action help')
+            parser.add_argument("--version", action="version", version=self.version)
+        subparsers = parser.add_subparsers(dest="action", help="Action help")
         subparsers.required = self.required
         actions = {}
         for cmd in self.subcommands:
@@ -51,18 +53,17 @@ class Subcommands:
 
 
 class Subcommand(SubcommandBase):
-    """A single subcommand corresponding to a function f of the main workflow
-    """
+    """A single subcommand corresponding to a function f of the main workflow"""
 
     def __init__(self, f, **kwargs):
         omit = frozenset(getattr(f, "keywords", ()))
         omit_pos = frozenset(range(len(getattr(f, "args", ()))))
-        args = arguments_by_signature(f,
-                                      omit_positionals=omit_pos,
-                                      omit_keywords=omit,
-                                      **kwargs)
-        super().__init__(name=kebab_case(f.__name__), action=f,
-                         arguments=tuple(args), help=f.__doc__)
+        args = arguments_by_signature(
+            f, omit_positionals=omit_pos, omit_keywords=omit, **kwargs
+        )
+        super().__init__(
+            name=kebab_case(f.__name__), action=f, arguments=tuple(args), help=f.__doc__
+        )
 
     def add_to_parser(self, parser, actions):
         subparser = parser.add_parser(self.name, help=self.help)
@@ -78,10 +79,12 @@ class SubcommandGroup(SubcommandBase):
     def __init__(self, name, *fcts, help=None):  # pylint: disable=redefined-builtin
         def call(f):
             f()
-        arguments = (Argument("--" + f.__name__, action="store_const",
-                              dest="f", const=f) for f in fcts)
-        super().__init__(name=name, action=call,
-                         arguments=arguments, help=help)
+
+        arguments = (
+            Argument("--" + f.__name__, action="store_const", dest="f", const=f)
+            for f in fcts
+        )
+        super().__init__(name=name, action=call, arguments=arguments, help=help)
 
     def add_to_parser(self, parser, actions):
         actions[self.name] = self.action
@@ -103,40 +106,50 @@ class Argument:
     def primitive(cls, dest, arg_names, **kwargs):
         return (cls(*arg_names, dest=dest, **kwargs),)
 
+    @classmethod
+    def bool(cls, dest, arg_names, positional: bool, **kwargs):
+        if positional:
+            return cls.positional_bool(dest, arg_names, **kwargs)
+        return cls.keyword_bool(dest, arg_names, **kwargs)
+
     @classmethod
     def positional_bool(cls, dest, arg_names, **kwargs):
         return cls.primitive(dest, arg_names, type=parse_bool, **kwargs)
 
     @classmethod
-    def keyword_bool(cls, dest, arg_names, default=False, help=None, **kwargs):  # pylint: disable=redefined-builtin
+    def keyword_bool(
+        cls, dest, arg_names, default=False, help=None, **kwargs
+    ):  # pylint: disable=redefined-builtin
         kwargs.pop("required", None)
         long_arg_names = tuple(filter(lambda n: n.startswith("--"), arg_names))
-        short_arg_names = tuple(
-            filter(lambda n: n not in long_arg_names, arg_names))
-        negation_flags = tuple(
-            a.replace("--", "--no-") for a in long_arg_names)
+        short_arg_names = tuple(filter(lambda n: n not in long_arg_names, arg_names))
+        negation_flags = tuple(a.replace("--", "--no-") for a in long_arg_names)
         default_flags = arg_names if default else negation_flags
         if short_arg_names and default:
             raise ValueError(
-                "booleans with short argument name and default=True are not supported")
+                "booleans with short argument name and default=True are not supported"
+            )
         if help:
             help += " "
         else:
             help = ""
         help += f"(disable with {', '.join(negation_flags)}, default: {', '.join(default_flags)})"
         return ArgumentMutExGroup(
-            cls(*arg_names,
+            cls(
+                *arg_names,
                 action="store_true",
                 dest=dest,
                 default=default,
                 help=help,
-                **kwargs),
-            cls(*negation_flags,
+                **kwargs,
+            ),
+            cls(
+                *negation_flags,
                 action="store_false",
                 default=default,
                 dest=dest,
-                help=argparse.SUPPRESS
-                )
+                help=argparse.SUPPRESS,
+            ),
         )
 
 
@@ -160,9 +173,9 @@ def decorate(f, *decorators):
 _origin_attr = "__extra__" if sys.version_info < (3, 7) else "__origin__"
 
 
-def arguments_by_signature(f, overrides=None,
-                           omit_keywords=frozenset(),
-                           omit_positionals=frozenset()) -> Generator[Argument, None, None]:
+def arguments_by_signature(
+    f, overrides=None, omit_keywords=frozenset(), omit_positionals=frozenset()
+) -> Generator[Argument, None, None]:
     """Builds argparser arguments according to the signature of a function f.
     Type hint annotations are used to infer the type for argparse"""
     sig = inspect.signature(f)
@@ -170,50 +183,47 @@ def arguments_by_signature(f, overrides=None,
         overrides = {}
     unknown_parameters = set(overrides) - set(sig.parameters)
     if unknown_parameters:
-        raise ValueError("Function {} does not have arguments {} "
-                         "(which have been provided as parameter docs)".format(
-                             f.__name__, ", ".join(unknown_parameters)))
+        raise ValueError(
+            "Function {} does not have arguments {} "
+            "(which have been provided as parameter docs)".format(
+                f.__name__, ", ".join(unknown_parameters)
+            )
+        )
     has_keyword_only = any(
-        p.kind is inspect.Parameter.KEYWORD_ONLY
-        for p in sig.parameters.values())
+        p.kind is inspect.Parameter.KEYWORD_ONLY for p in sig.parameters.values()
+    )
     for pos, (p_name, p) in enumerate(sig.parameters.items()):
         if p_name in omit_keywords or pos in omit_positionals:
             continue
-        positional = has_keyword_only and \
-            p.kind is not inspect.Parameter.KEYWORD_ONLY
+        positional = has_keyword_only and p.kind is not inspect.Parameter.KEYWORD_ONLY
         p_overrides = overrides.get(p_name, {})
-        arg_names = make_arg_names(p_overrides.get(
-            "name", kebab_case(p_name) if not positional else p_name),
-            p_overrides.get("alias", ()), positional)
+        arg_names = make_arg_names(
+            p_overrides.get("name", kebab_case(p_name) if not positional else p_name),
+            p_overrides.get("alias", ()),
+            positional,
+        )
         default = p_overrides.get("default", p.default)
         args = dict(help=p_overrides.get("help"))
         t = p_overrides.get("type", p.annotation)
         if t is inspect.Signature.empty:
             raise ValueError(f"Argument {arg_names[0]} has no type annotation")
-        opt_type = optional_type(t)
-        if opt_type is not None:
-            if default is inspect.Signature.empty:
-                raise ValueError(
-                    f"{f.__name__}: {p_name}: typing.Optional arguments are "
-                    "allowed only when accompanied with a default value")
-            t = opt_type
+        try:
+            t = unwrap_opt(t, default)
+        except ValueError as e:
+            raise ValueError(f"{f.__name__}: {p_name}: {e}") from None
 
         if not positional:
             args["dest"] = p_overrides.get("dest", p_name)
             args.update(default_args(default))
         if t is bool:
-            if positional:
-                yield Argument.positional_bool(arg_names=arg_names,
-                                               **args)
-            else:
-                yield Argument.keyword_bool(arg_names=arg_names, **args)
+            yield Argument.bool(arg_names=arg_names, positional=positional, **args)
             continue
         if is_sequence(t):
             t = getattr(t, "__args__", (str,))[0]
             if default is not inspect.Signature.empty:
                 args["default"] = default
             if positional:
-                args["nargs"] = '+' if default is inspect.Signature.empty else '*'
+                args["nargs"] = "+" if default is inspect.Signature.empty else "*"
             else:
                 args["action"] = "append"
         yield Argument(*arg_names, type=t, **args)
@@ -233,8 +243,7 @@ def make_arg_names(name, aliases, positional: bool):
     arg_prefix = "-" * n_dashes
     if positional:
         if aliases:
-            raise ValueError(
-                "Aliases not allowed for positional arguments")
+            raise ValueError("Aliases not allowed for positional arguments")
         arg_prefix = ""
     arg_names = (arg_prefix + name,)
     if isinstance(aliases, str):
@@ -246,8 +255,8 @@ bool_true_literals = ("1", "true", "y", "yes")
 bool_false_literals = ("0", "false", "n", "no")
 
 bool_literal_mapping = dict(
-    [(l, True) for l in bool_true_literals] +
-    [(l, False) for l in bool_false_literals])
+    [(l, True) for l in bool_true_literals] + [(l, False) for l in bool_false_literals]
+)
 
 
 def parse_bool(s):
@@ -256,20 +265,21 @@ def parse_bool(s):
 
 def is_sequence(t):
     t_origin = getattr(t, "__origin__", None)
-    return isinstance(t_origin, type) and \
-        issubclass(t_origin, collections.abc.Sequence)
+    return isinstance(t_origin, type) and issubclass(t_origin, collections.abc.Sequence)
 
 
 def partial(*args, **kwargs):
     """Modified version of :functools.partial: which preserves
     __name__ and __doc__ attributes and can be used as a decorator
     """
+
     def decorator(f):
         keywords = getattr(f, "keywords", {})
         f_new = ft_partial(f, *args, **{**keywords, **kwargs})
         f_new.__name__ = f.__name__
         f_new.__doc__ = f.__doc__
         return f_new
+
     return decorator
 
 
@@ -277,11 +287,11 @@ def lazy_partial(*args, **kwargs):
     """Similar to :functools.partial: but load bound arguments at runtime of
     the wrapped function, by calling the arguments.
     """
+
     def decorator(f):
         @wraps(f)
         def wrapped_f(*_args, **_kwargs):
-            newkeywords = {key: val()
-                           for key, val in kwargs.items()}
+            newkeywords = {key: val() for key, val in kwargs.items()}
             newkeywords.update(_kwargs)
             return f(*map(lambda f: f(), args), *_args, **newkeywords)
 
@@ -291,39 +301,49 @@ def lazy_partial(*args, **kwargs):
         wrapped_f.keywords = new_keywords
 
         return wrapped_f
+
     return decorator
 
 
 def set_default(**defaults):
     """Sets or changes default values of the decorated function"""
+
     def decorator(f):
         @wraps(f)
         def _f(*args, **kwargs):
             return f(*args, **{**defaults, **kwargs})
+
         return _f
+
     return decorator
 
 
 def rename(name: str):
     """Changes the name of a function"""
+
     def wrapper(f):
         def wrapped(*args, **kwargs):
             return f(*args, **kwargs)
+
         wrapped.__name__ = name
         return wrapped
+
     return wrapper
 
 
 def block(*arg_names: str):
     """Hides argument of a function from arguments_by_signature"""
+
     def wrapper(f):
         @wraps(f)
         def wrapped(*args, **kwargs):
             return f(*args, **kwargs)
+
         keywords = getattr(wrapped, "keywords", {})
         keywords.update({n: object() for n in arg_names})
         wrapped.keywords = keywords
         return wrapped
+
     return wrapper
 
 
@@ -336,6 +356,7 @@ def return_to_stdout(f):
     @wraps(f)
     def wrapper(*args, **kwargs):
         pp.pprint(f(*args, **kwargs))
+
     return wrapper
 
 
@@ -343,6 +364,17 @@ def kebab_case(name):
     return name.replace("_", "-")
 
 
+def unwrap_opt(t: type, default) -> type:
+    opt_type = optional_type(t)
+    if opt_type is None:
+        return t
+    if default is inspect.Signature.empty:
+        raise ValueError(
+            "typing.Optional arguments are allowed only when accompanied with a default value"
+        )
+    return opt_type
+
+
 def optional_type(T: type) -> Optional[type]:
     """For Optional types provided by typing, return the underlying python type,
     else None.
