@@ -1,6 +1,6 @@
 from functools import partial
 
-from .component import TabMixin, PathInput, GuiProgress, run_dialog
+from .component import TabMixin, PathInput, GuiProgress, get_text_input
 from .file_selection_widget import ArchiveOnlyFileSelectionWidget
 from .parallel import Worker
 from .pyside import QtCore, QtWidgets
@@ -70,7 +70,7 @@ class DecryptTab(QtWidgets.QWidget, TabMixin):
         progress = GuiProgress()
         progress.updated.connect(self.progress_bar.setValue)
         if not dry_run:
-            pw = run_dialog(self, "Enter password for your GPG key")
+            pw = get_text_input(self, "Enter password for your GPG key")
             if pw is None:
                 return
         else:
