@@ -31,7 +31,8 @@ def encrypt_workflow(*args, **kwargs):
         encrypt.encrypt(*args, **kwargs)
     except OutOfSpaceError as e:
         raise OutOfSpaceError(
-            f"{e} Use the checkbox '{ignore_disk_space_error_label}' in the output box to ignore this error.",
+            f"{e} Use the checkbox '{ignore_disk_space_error_label}' in the "
+            "output box to ignore this error.",
         ) from e
 
 
@@ -284,7 +285,6 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
             output=self.app_data.encrypt_output_location,
             output_suffix=self.app_data.encrypt_output_suffix,
             dry_run=dry_run,
-            offline=self.app_data.config.offline,
             compression_level=self.app_data.encrypt_compression_level,
             purpose=self.app_data.encrypt_purpose,
             progress=progress,
