@@ -129,6 +129,7 @@ class AppData:
     encrypt_files: List[str] = field(default_factory=list)
     encrypt_verify_dtr: bool = True
     encrypt_package_name_suffix: str = ""
+    encrypt_ignore_disk_space_error: bool = False
 
     decrypt_decrypt_only: bool = False
     decrypt_output_location: Path = field(default_factory=Path.home)
@@ -146,13 +147,19 @@ class AppData:
     validation_authority_key: Optional[gpg.Key] = None
 
     def __setattr__(self, attr, value):
+        # Each time an attribute is set, check whether it is being watched,
+        # and if so, run the associated functions.
         super().__setattr__(attr, value)
         if hasattr(self, "_listeners"):
             for callback in self._listeners[attr]:
                 callback()
 
-    def add_listener(self, attr, listener: Callable):
-        self._listeners[attr].append(listener)
+    def add_listener(self, attr, callback: Callable):
+        """Add a listener to the specified attribute. Each time the value of
+        the attributed will change, the specified callback function(s) will
+        be called.
+        """
+        self._listeners[attr].append(callback)
 
     def __post_init__(self):
         # pylint: disable=attribute-defined-outside-init
