@@ -1,11 +1,13 @@
 import logging
+import platform
 import sys
 import traceback
+import warnings
 from typing import Sequence, Callable, Optional, cast
 from contextlib import contextmanager
 
 from .pyside import QtCore
-from ..utils.log import LOG_FORMAT
+from ..utils.log import EmojiLevelFormatter, LOG_FORMAT, LOG_FORMAT_WITH_EMOJI, LogStyle
 from ..utils.error_handling import (
     suppress_exceptions,
     log_exceptions,
@@ -22,9 +24,14 @@ class LoggerHandler(logging.Handler):
         super().__init__(level)
         self.callback = callback
 
-    def emit(self, record):
+    def emit(self, record: logging.LogRecord):
         if self.callback:
-            self.callback(self.format(record))
+            color = LogStyle.HTML.get_style(record.levelno)
+            self.callback(
+                f'<span style="color: {color}">{self.format(record)}</span>'
+                if color
+                else self.format(record)
+            )
 
 
 class WorkerSignals(QtCore.QObject):
@@ -34,6 +41,7 @@ class WorkerSignals(QtCore.QObject):
     result = QtCore.Signal(object)
     progress = QtCore.Signal(int)
     logging = QtCore.Signal(str)
+    warning = QtCore.Signal(str)
 
 
 class Worker(QtCore.QRunnable):
@@ -57,16 +65,23 @@ class Worker(QtCore.QRunnable):
         **kwargs,
     ):
         super().__init__()
+
+        # If no specific logger was passed to the worker, create a default
+        # logger that will print warnings and errors to the app's log file.
         logger = (
             capture_loggers[0] if capture_loggers else cast(logging.Logger, logging)
         )
-        # Somehow pyling does not know, that @contextmanager also is a decorator:
+        self.fn = log_exceptions(logger=logger, reraise_warnings=not capture_loggers)(
+            fn
+        )
+
+        # Somehow pylint does not know that @contextmanager is also a decorator.
         sanitized_args, sanitized_kwargs = enforce_secret_by_signature(fn, args, kwargs)
         workflow_args_info = ",\n  ".join(
             [repr(arg) for arg in sanitized_args]
             + [f"{key}={repr(val)}" for key, val in sanitized_kwargs.items()]
         )
-        self.fn = log_exceptions(logger=logger)(fn)
+
         if report_config.error_reports:
             self.fn = error_report_on_exception(  # pylint: disable=not-callable
                 report_config,
@@ -82,7 +97,9 @@ class Worker(QtCore.QRunnable):
             self.signals.error.connect(lambda err: forward_errors(err[1]))
 
     def run(self) -> None:
-        with attach_loggers_to_signals(self.capture_loggers, self.signals):
+        with attach_loggers_to_signals(
+            self.capture_loggers, self.signals
+        ), warnings.catch_warnings(record=True) as user_warnings:
             try:
                 self.signals.started.emit()
                 self.signals.logging.emit(RUNTIME_INFO)
@@ -92,13 +109,22 @@ class Worker(QtCore.QRunnable):
                 self.signals.error.emit((exctype, value, traceback.format_exc()))
             else:
                 self.signals.result.emit(result)
+
+        if user_warnings:
+            self.signals.warning.emit(
+                "\n".join(format(w.message) for w in user_warnings)
+            )
         self.signals.finished.emit()
 
 
 @contextmanager
 def attach_loggers_to_signals(loggers, signals):
     logger_handler = LoggerHandler(callback=signals.logging.emit)
-    logger_handler.setFormatter(logging.Formatter(LOG_FORMAT))
+    logger_handler.setFormatter(
+        logging.Formatter(LOG_FORMAT)
+        if platform.system() == "Windows"
+        else EmojiLevelFormatter(LOG_FORMAT_WITH_EMOJI)
+    )
     logger_handler.setLevel(logging.INFO)
     for logger in loggers:
         logger.addHandler(logger_handler)
