@@ -1,4 +1,5 @@
 import copy
+import os
 from typing import Optional, Dict
 
 from .component import PathInput, FieldMapping, create_slider, LineEdit, SpinBox
@@ -93,6 +94,18 @@ class SettingsTab(QtWidgets.QWidget):
             0,
             9,
         )
+
+        self._add_widget_int_range(
+            encrypt_decrypt_group,
+            "Max CPU",
+            "max_cpu",
+            "Maximum number of CPU cores for parallel computation (use all CPU cores if value equals 0)",
+            0,
+            # In case cpu_count fails to detect the number of available cores
+            # use a reasonable default
+            os.cpu_count() or 4,
+        )
+
         self._add_widget_str(
             encrypt_decrypt_group,
             "Default sender",
@@ -132,6 +145,7 @@ class SettingsTab(QtWidgets.QWidget):
             "Default suffix for encrypted package name",
             regex=PACKAGE_SUFFIX,
         )
+
         pgp_keys_group = self._add_group("PGP keys")
         self._add_widget_str(
             pgp_keys_group,
@@ -150,12 +164,25 @@ class SettingsTab(QtWidgets.QWidget):
             True,
         )
         # no validation, as specifying http:// is optional
-        self._add_widget_str(
+        self.field_keyserver_url = self._add_widget_str(
             pgp_keys_group,
             "Keyserver URL",
             "keyserver_url",
             "URL of the keyserver: used for publishing/fetching public PGP keys.",
         )
+        self.checkbox_gpg_key_autodownload = self._add_widget_bool(
+            pgp_keys_group,
+            "Allow PGP key auto-download",
+            "gpg_key_autodownload",
+            "Allow the automatic download and refresh of PGP keys from the Keyserver.",
+        )
+        # Enable or disable the PGP key auto-download checkbox option based on
+        # whether a keyserver URL value is provided or not.
+        self._enable_checkbox_key_autodownload()
+        self.field_keyserver_url.textChanged.connect(
+            self._enable_checkbox_key_autodownload
+        )
+
         data_transfer_group = self._add_group("Data transfer")
         self._add_widget_str(
             data_transfer_group,
@@ -171,6 +198,7 @@ class SettingsTab(QtWidgets.QWidget):
             "DTR (Data Transfer Request) validation.",
             REGEX_URL,
         )
+
         sett_updates_group = self._add_group("sett updates")
         self._add_widget_str(
             sett_updates_group,
@@ -185,6 +213,7 @@ class SettingsTab(QtWidgets.QWidget):
             "check_version",
             "Check whether you have the latest version of sett on startup",
         )
+
         misc_log_group = self._add_group("Miscellaneous and logs")
         self._add_widget_bool(
             misc_log_group,
@@ -254,7 +283,7 @@ class SettingsTab(QtWidgets.QWidget):
         config_key: str,
         status_tip: str,
         regex: Optional[str] = None,
-    ):
+    ) -> QtWidgets.QLineEdit:
         widget = self.field_mapping.bind_text(config_key, LineEdit())
         widget.setStatusTip(status_tip)
         if regex:
@@ -271,6 +300,7 @@ class SettingsTab(QtWidgets.QWidget):
             row,
             1,
         )
+        return widget
 
     def _add_widget_path(
         self,
@@ -301,7 +331,7 @@ class SettingsTab(QtWidgets.QWidget):
         label: str,
         config_key: str,
         status_tip: str,
-    ):
+    ) -> QtWidgets.QCheckBox:
         widget = self.field_mapping.bind_checked(config_key, QtWidgets.QCheckBox())
         widget.setStatusTip(status_tip)
 
@@ -316,6 +346,7 @@ class SettingsTab(QtWidgets.QWidget):
             row,
             1,
         )
+        return widget
 
     def _add_widget_int(
         self,
@@ -368,3 +399,8 @@ class SettingsTab(QtWidgets.QWidget):
         layout.addWidget(QtWidgets.QLabel(label), row, 0)
         layout.addWidget(slider, row, 1)
         layout.addWidget(slider_value, row, 2)
+
+    def _enable_checkbox_key_autodownload(self):
+        self.checkbox_gpg_key_autodownload.setEnabled(
+            len(self.field_keyserver_url.text().strip()) > 0
+        )
