@@ -61,6 +61,8 @@ class Config:
     gui_quit_confirmation: bool = True
     compression_level: int = 5
     package_name_suffix: Optional[str] = None
+    max_cpu: int = 0
+    gpg_key_autodownload: bool = True
 
     def __post_init__(self):
         for url in ("dcc_portal_url", "repo_url"):
@@ -74,6 +76,24 @@ class Config:
     def gpg_store(self):
         return open_gpg_dir(self.gpg_home_dir)
 
+    @property
+    def allow_gpg_key_autodownload(self) -> bool:
+        """Property indicating whether GPG keys can be automatically downloaded
+        and refreshed from a keyserver, if a keyserver is specified.
+        Key auto-download is not allowed in the following situations:
+         * There is no defined validation authority. If keys do not need to be
+           certified by a central key authority, auto-downloading them presents
+           a security risk (keys should be manually downloaded and checked) and
+           is therefore not allowed.
+         * The 'offline' mode is activated, no network access is allowed.
+         * The user has decided to not allow it.
+        """
+        return (
+            self.key_authority_fingerprint is not None
+            and not self.offline
+            and self.gpg_key_autodownload
+        )
+
 
 class ConnectionStore:
     """Connection configuration storage manager"""
