@@ -208,8 +208,7 @@ def scale_progress(
             """Rescale the completed_fraction value so that its value is
             in the range [start-stop].
             """
-            if completed_fraction > 1:
-                completed_fraction = 1
+            completed_fraction = min(completed_fraction, 1)
             progress.update(start + completed_fraction * (stop - start))
 
         def get_completed_fraction(self) -> float:
@@ -341,8 +340,10 @@ class Opener:
         self.wrapper = wrapper
 
     def __enter__(self):
-        self._f = open(self.name, self.mode)
-        self._f.__enter__()
+        # Impossible to use `with` if you want to wrap `__enter__`, `__exit__`.
+        # Workaround would be contextlib.contextmanager. But then you cannot set the
+        # `name`, `mode` attributes on the contextmanager object without breaking mypy.
+        self._f = open(self.name, self.mode)  # pylint: disable=consider-using-with
         return self.wrapper(self._f.__enter__())
 
     def __exit__(self, *args):
