@@ -24,7 +24,14 @@ from ..core.crypt import (
     verify_metadata_signature,
     gpg,
 )
-from ..core.filesystem import DeleteDirOnError, unique_filename, check_space
+from ..core.filesystem import (
+    DeleteDirOnError,
+    get_compression_stats,
+    get_total_size,
+    to_human_readable_size,
+    unique_filename,
+    check_space,
+)
 from ..core.checksum import (
     verify_checksums,
     compute_checksum_sha256,
@@ -54,21 +61,17 @@ def decrypt(
     """Decrypt and decompress an input .tar file."""
 
     logger.info(
-        """Input summary:
-    file(s) to decrypt: %s
-    output_dir: %s
-    dry_run: %s
-""",
-        "\n\t".join(files),
+        "File(s) to decrypt: [%s], output_dir: %s%s",
+        ", ".join(files),
         output_dir,
-        dry_run,
+        " (dry_run)" if dry_run else "",
     )
 
     with logger.log_task("Input data check"):
         for archive_path in files:
             check_package(archive_path)
 
-    check_space(files, output_dir, force=False)
+    check_space(get_total_size(files), output_dir, force=False)
 
     if dry_run:
         logger.info("Dry run completed successfully")
@@ -78,7 +81,6 @@ def decrypt(
         # Reset progress for each tar file
         if progress is not None:
             progress.update(0.0)
-        logger.info("Processing file %s", archive_file)
         decrypt_archive(
             archive_file,
             passphrase=passphrase,
@@ -87,7 +89,6 @@ def decrypt(
             decrypt_only=decrypt_only,
             progress=progress,
         )
-        logger.info("Data decryption completed successfully.")
 
 
 def decrypt_archive(
@@ -98,7 +99,7 @@ def decrypt_archive(
     decrypt_only: bool = False,
     progress: Optional[ProgressInterface] = None,
 ):
-
+    logger.info("Processing file %s", archive_file)
     # To avoid overwriting files, each archive is unpacked in a directory
     # that has the same name as the archive file minus its extension.
     out_dir = unique_filename(
@@ -125,14 +126,12 @@ def decrypt_archive(
                     gpg_store=config.gpg_store,
                     key_authority_fingerprint=config.key_authority_fingerprint,
                     keyserver_url=config.keyserver_url,
+                    allow_key_download=config.allow_gpg_key_autodownload,
                 )
             )
             logger.info(
-                "Data encrypted for:\n%s",
-                "\n".join(
-                    f"User ID    : {key.uids[0]}\nFingerprint: {key.fingerprint}"
-                    for key in keys
-                ),
+                "Data encrypted for: %s",
+                ", ".join(f"{key.uids[0]} ({key.fingerprint})" for key in keys),
             )
             check_password_matches_any_key(
                 password=enforce_passphrase(passphrase),
@@ -152,6 +151,7 @@ def decrypt_archive(
             if metadata.checksum.lower() != compute_checksum_sha256(f_data):
                 raise UserError(f"Checksum mismatch for {f_data.name}")
 
+        unpacked_files: List[str] = list()
         with logger.log_task("Decrypting data..."), subprogress(
             progress, step_completion_increase=0.9
         ) as scaled_progress, extract_with_progress(
@@ -166,44 +166,65 @@ def decrypt_archive(
                     passphrase=passphrase,
                 )
             else:
-                unpacked: List[str] = list()
                 sender_fprs = core_decrypt(
                     source=f_data,
-                    output=partial(unpack_from_stream, dest=out_dir, content=unpacked),
+                    output=partial(
+                        unpack_from_stream, dest=out_dir, content=unpacked_files
+                    ),
                     gpg_store=config.gpg_store,
                     passphrase=passphrase,
                 )
-                log_files(unpacked)
             sender_sig_keys = retrieve_refresh_and_validate_keys(
                 key_search_terms=map(fingerprint2keyid, sender_fprs),
                 gpg_store=config.gpg_store,
                 key_authority_fingerprint=config.key_authority_fingerprint,
                 keyserver_url=config.keyserver_url,
+                allow_key_download=config.allow_gpg_key_autodownload,
             )
             logger.info(
-                "Data signed by:\n%s",
-                "\n".join(
-                    f"User ID    : {key.uids[0]}\n" f"Fingerprint: {key.fingerprint}"
-                    for key in sender_sig_keys
+                "Data signed by: %s",
+                ", ".join(
+                    f"{key.uids[0]} ({key.fingerprint})" for key in sender_sig_keys
                 ),
             )
 
         with subprogress(progress, step_completion_increase=0.05) as scaled_progress:
-            if not decrypt_only:
+            if decrypt_only:
+                decryption_stats = "size: " + to_human_readable_size(
+                    os.path.getsize(archive_file)
+                )
+            else:
                 with logger.log_task(
                     "Checksum verification of uncompressed data..."
                 ), open(os.path.join(out_dir, CHECKSUM_FILE), "rb") as fout:
-                    sha_checks = list(read_checksum_file(fout))
-                    verify_checksums(sha_checks, out_dir)
+                    # Path separator replacement is a fail-safe if paths are not POSIX.
+                    verify_checksums(
+                        [
+                            (c, os.path.join(out_dir, p.replace("\\", os.path.sep)))
+                            for c, p in read_checksum_file(fout)
+                        ],
+                        # `max_workers` accepts only None and positive integers. Make
+                        # sure that zero and negative values are converted into None.
+                        max_workers=config.max_cpu if config.max_cpu > 0 else None,
+                    )
+                log_files(unpacked_files)
+                decryption_stats = get_compression_stats(
+                    os.path.getsize(archive_file),
+                    get_total_size(os.path.join(out_dir, f) for f in unpacked_files),
+                    compression=False,
+                )
             if scaled_progress is not None:
                 scaled_progress.update(1.0)
+            logger.info(
+                "Completed data decryption: %s (%s)", archive_file, decryption_stats
+            )
 
 
 def log_files(files: List[str]):
-    max_files_to_list = 50
+    max_files_to_list = 5
     d_n = len(files) - max_files_to_list
     logger.info(
-        "List of extracted files: \n\t%s%s",
-        "\n\t".join(files[:max_files_to_list]),
-        ((f"\n\t and {d_n} more files " "- not listing them all.") if d_n > 0 else ""),
+        "Extracted files: [%s] %s",
+        ", ".join(files[:max_files_to_list]),
+        ((f"and {d_n} more files - not listing them all.") if d_n > 0 else ""),
     )
