@@ -22,6 +22,8 @@ from ..core.archive import (
 )
 from ..core.filesystem import (
     delete_file_on_error,
+    get_compression_stats,
+    get_total_size,
     search_files_recursively,
     check_file_read_permission,
     check_space,
@@ -35,7 +37,7 @@ from ..core.crypt import (
     search_priv_key,
     gpg,
 )
-from ..core.checksum import write_checksums, compute_checksum_on_write
+from ..core.checksum import generate_checksums_file_content, compute_checksum_on_write
 from ..core.error import UserError
 from ..core.metadata import MetaData, alnum_str, Purpose, HexStr1024, HexStr256
 from ..core.secret import Secret
@@ -97,11 +99,26 @@ def check_integer_in_range(min_value: int, max_value: int) -> Callable:
     return _integer_in_range
 
 
+def check_paths_on_posix(paths: Iterable[str]):
+    """Check paths for windows-style separators.
+
+    If the machine is POSIX, verify that the specified paths do not contain
+    any windows-style separators.
+    """
+
+    for path in paths:
+        if os.path.sep == "/" and "\\" in path:
+            raise UserError(
+                "On POSIX systems (this machine), backslashes are NOT allowed "
+                f"as path separators. Offending value is [{path}]"
+            )
+
+
 check_compression_level = check_integer_in_range(min_value=0, max_value=9)
 
 
 @log_timing(logger)
-def encrypt(
+def encrypt(  # pylint: disable=too-many-statements
     files: List[str],
     *,
     config: Config,
@@ -112,7 +129,6 @@ def encrypt(
     output: Optional[str] = None,
     output_suffix: Optional[str] = None,
     dry_run: bool = False,
-    offline: bool = False,
     verify_dtr: bool = True,
     force: bool = False,
     compression_level: Optional[int] = None,
@@ -121,7 +137,7 @@ def encrypt(
 ) -> Optional[str]:
     """Compress and encrypt files and/or directories.
 
-    Returns the file name of the created package
+    Returns the file name of the created package.
     """
 
     # Retrive non-specified, optional argument values from config.
@@ -168,8 +184,9 @@ def encrypt(
             key_search_terms=(sender, *recipient),
             gpg_store=config.gpg_store,
             key_authority_fingerprint=config.key_authority_fingerprint,
-            keyserver_url=config.keyserver_url if not offline else None,
+            keyserver_url=config.keyserver_url,
             validate_key_origin=False,
+            allow_key_download=config.allow_gpg_key_autodownload,
         )
 
         # Verify a private key matching the user's public key exists. The key
@@ -178,21 +195,17 @@ def encrypt(
         search_priv_key(sender_pub_key.fingerprint, config.gpg_store)
 
         logger.info(
-            "found the following keys:\n%s\n%s",
-            f"sender key: {sender_pub_key.uids[0]}, "
-            f"key ID: {sender_pub_key.key_id}",
-            "\n".join(
-                [
-                    f"recipient key: {key.uids[0]}, " f"key ID: {key.key_id}"
-                    for key in recipients_pub_key
-                ]
+            "Sender: %s. Recipients: %s",
+            f"{sender_pub_key.uids[0]} ({sender_pub_key.fingerprint})",
+            ", ".join(
+                f"{key.uids[0]} ({key.fingerprint})" for key in recipients_pub_key
             ),
         )
 
     project_code = determine_project_code(
         dtr_id,
         purpose,
-        config.portal_api if not offline and verify_dtr else None,
+        config.portal_api if not config.offline and verify_dtr else None,
         sender_pub_key,
         recipients_pub_key,
     )
@@ -214,10 +227,20 @@ def encrypt(
             )
         ),
     )
-    check_space(files_to_encrypt, os.path.dirname(output_name), force=force)
+    total_input_file_size = get_total_size(files_to_encrypt)
+    check_space(total_input_file_size, os.path.dirname(output_name), force=force)
+
+    # Create a list of file paths (of the files that are being packaged) as they
+    # will appear in the output archive file.
+    archive_paths = [
+        os.path.join(CONTENT_FOLDER, os.path.relpath(f, start=root_dir))
+        for f in files_to_encrypt
+    ]
+
+    check_paths_on_posix(archive_paths)
 
     if dry_run:
-        logger.info("dry run completed successfully.")
+        logger.info("Dry run completed successfully")
         return None
 
     # If the user asked to sign the data, check that the GPG key password
@@ -229,24 +252,18 @@ def encrypt(
             gpg_store=config.gpg_store,
         )
 
-    archive_paths = [
-        os.path.join(CONTENT_FOLDER, os.path.relpath(f, start=root_dir))
-        for f in files_to_encrypt
-    ]
-
     with logger.log_task("Compute sha256 checksum on input files"):
         # Write input file checksums to a file that will be added to the
         # encrypted .tar.gz archive. This information must be encrypted as
         # file names sometimes contain information about their content.
-        with subprogress(progress, step_completion_increase=0.2) as scaled_progress:
-            checksums = write_checksums(
-                zip(
-                    archive_paths,
-                    progress_file_iter(
-                        files=files_to_encrypt, mode="rb", progress=scaled_progress
-                    ),
-                )
-            )
+        checksums = generate_checksums_file_content(
+            zip(archive_paths, files_to_encrypt),
+            # `max_workers` accepts only None and positive integers. Make
+            # sure that zero and negative values are converted into None.
+            max_workers=config.max_cpu if config.max_cpu > 0 else None,
+        )
+        if progress is not None:
+            progress.update(0.1)
 
     with logger.log_task("Compress and encrypt input data [this can take a while]"):
         # Encryption is done with the recipient's public key and the optional
@@ -256,7 +273,7 @@ def encrypt(
         with delete_file_on_error(output_name), ZipFile(
             output_name, mode="w", compression=ZIP_STORED
         ) as zip_obj:
-            with subprogress(progress, step_completion_increase=0.8) as scaled_progress:
+            with subprogress(progress, step_completion_increase=0.9) as scaled_progress:
                 # Create a tar archive containing all input files
                 archive_content: Tuple[ArchiveFileBase, ...] = (
                     ArchiveInMemoryFile(CHECKSUM_FILE, checksums),
@@ -330,7 +347,11 @@ def encrypt(
                     contents,
                 )
 
-    logger.info("Completed data encryption: %s", output_name)
+    logger.info(
+        "Completed data encryption: %s (%s)",
+        output_name,
+        get_compression_stats(total_input_file_size, os.path.getsize(output_name)),
+    )
     return output_name
 
 
