@@ -1,6 +1,5 @@
-from typing import List
+from typing import Sequence
 
-from . import workflow
 from .upload_keys import upload_keys
 from ..core.crypt import verify_key_length, search_pub_key
 from ..core.error import UserError
@@ -11,8 +10,7 @@ from ..utils.config import Config
 logger = create_logger(__name__)
 
 
-@workflow(logger, UserError)
-def request_sigs(key_ids: List[str], *, config=Config):
+def request_sigs(key_ids: Sequence[str], *, config=Config):
     """Requests signatures"""
     if config.offline:
         raise UserError("Requesting key signature is not possible in offline mode.")
