@@ -27,11 +27,9 @@ def transfer(
     """Transfer file(s) to the selected recipient on the BiomedIT network."""
 
     logger.info(
-        """Input summary:
-    files to transfer: %s"
-    dry run          : %s""",
-        "\n\t".join(files),
-        str(dry_run),
+        "File(s) to transfer: [%s]%s",
+        ", ".join(files),
+        " (dry_run)" if dry_run else "",
     )
 
     with logger.log_task("Input data check"):
@@ -39,9 +37,9 @@ def transfer(
             check_package(archive_path)
 
     files_by_recipient: Dict[Tuple[gpg.Key, ...], List[str]] = {}
-    with logger.log_task("Extracting destination for each file to transfer"):
+    with logger.log_task("Extracting destination for each package"):
         for archive_path in files:
-            logger.info("\t-> %s", archive_path)
+            logger.info("Processing: %s", archive_path)
             with extract(archive_path, METADATA_FILE, DATA_FILE_ENCRYPTED) as (
                 metadata,
                 encrypted_file,
@@ -53,6 +51,7 @@ def transfer(
                         gpg_store=config.gpg_store,
                         key_authority_fingerprint=config.key_authority_fingerprint,
                         keyserver_url=config.keyserver_url,
+                        allow_key_download=config.allow_gpg_key_autodownload,
                     )
                 )
             metadata = load_metadata(metadata)
